@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.61';
+our $VERSION = '0.62';
 
 use Dist::Zilla 6.0;
 
@@ -44,7 +44,7 @@ use Dist::Zilla::Plugin::MojibakeTests;
 use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::PPPort;
 use Dist::Zilla::Plugin::PodSyntaxTests;
-use Dist::Zilla::Plugin::PromptIfStale;
+use Dist::Zilla::Plugin::PromptIfStale 0.050;
 use Dist::Zilla::Plugin::ReadmeAnyFromPod;
 use Dist::Zilla::Plugin::RunExtraTests;
 use Dist::Zilla::Plugin::SurgicalPodWeaver;
@@ -492,26 +492,34 @@ sub _explicit_prereq_plugins {
 }
 
 sub _prompt_if_stale_plugin {
-    return if $ENV{TRAVIS};
-
-    return [
-        'PromptIfStale' => {
-            phase             => 'build',
-            check_all_plugins => 1,
-            check_all_prereqs => 1,
-            skip              => [
-                qw(
-                    Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent
-                    Dist::Zilla::Plugin::DROLSKY::Contributors
-                    Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch
-                    Dist::Zilla::Plugin::DROLSKY::License
-                    Dist::Zilla::Plugin::DROLSKY::TidyAll
-                    Dist::Zilla::Plugin::DROLSKY::VersionProvider
-                    Pod::Weaver::PluginBundle::DROLSKY
-                    )
-            ],
-        }
-    ];
+    my $name = __PACKAGE__;
+    return (
+        [
+            'PromptIfStale' => $name => {
+                phase  => 'build',
+                module => [__PACKAGE__],
+            },
+        ],
+        [
+            'PromptIfStale' => {
+                phase             => 'release',
+                check_all_plugins => 1,
+                check_all_prereqs => 1,
+                check_authordeps  => 1,
+                skip              => [
+                    qw(
+                        Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent
+                        Dist::Zilla::Plugin::DROLSKY::Contributors
+                        Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch
+                        Dist::Zilla::Plugin::DROLSKY::License
+                        Dist::Zilla::Plugin::DROLSKY::TidyAll
+                        Dist::Zilla::Plugin::DROLSKY::VersionProvider
+                        Pod::Weaver::PluginBundle::DROLSKY
+                        )
+                ],
+            }
+        ],
+    );
 }
 
 sub _pod_test_plugins {
@@ -722,7 +730,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.61
+version 0.62
 
 =head1 DESCRIPTION
 
